#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon Feb  7 20:13:06 2022

@author: mmerkel
"""

import os
import sys
import numpy as np

def crop_amn_file(seed, n_wf, n_wf_full=None):
    with open(f'{seed}.amn', 'r') as file:
        file.readline()
        n_bands, n_k, _ = (int(s) for s in file.readline().split())

    if n_wf_full is None:
        n_wf_full = n_bands

    amn_data = np.loadtxt(f'{seed}.amn', skiprows=2)
    assert amn_data.shape[0] == n_k * n_bands * n_wf_full

    amn_data = amn_data.reshape((n_k, n_wf_full, n_bands, 5))
    amn_data_cropped = amn_data[:, :n_wf, :]

    with open(f'{seed}_corr.amn', 'w') as file:
        file.write('File generated by Vasp: manually cropped\n')
        file.write('{:>12}{:>12}{:>12}'.format(n_bands, n_k, n_wf))

        for d in amn_data_cropped.reshape(n_bands*n_k*n_wf, 5):
            file.write('\n{:>5}{:>5}{:>5}{:>18.12f}{:>18.12f}'.format(int(d[0]+.5), int(d[1]+.5),
                                                                      int(d[2]+.5), d[3], d[4]))

def main(seed, n_wf, n_wf_full=None):
    crop_amn_file(seed, n_wf, n_wf_full)
    # Links other files: .eig, .mmn
    try:
        os.symlink(f'{seed}.eig', f'{seed}_corr.eig')
    except FileExistsError as e:
       print(repr(e))
    try:
        os.symlink(f'{seed}.mmn', f'{seed}_corr.mmn')
    except FileExistsError as e:
       print(repr(e))

if __name__ == '__main__':
    assert len(sys.argv) in (3, 4), ('Give wannier seed, number of correlated functions'
                                     +'and optionally the original number of correlated functions')
    if len(sys.argv) == 3:
        main(sys.argv[1], int(sys.argv[2]))
    else:
        main(sys.argv[1], int(sys.argv[2]), int(sys.argv[3]))

